#ifndef ROOT_Event
#define ROOT_Event

#include "TObject.h"
#include "TClonesArray.h"

class Track : public TObject {
private:
  Int_t      fEvent;
  Int_t      fLayer;
public:
   Track() {; }
   Track(const Track& orig);
   Track(Int_t event, Int_t layer);
   virtual ~Track() {Clear();}
   void          Clear(Option_t *option="");
   void Print();

   ClassDef(Track, 1)  //A track segment
};



class Layer : public TObject {
 private:
  Int_t          fN; // layer number
  Int_t          fNtrack;            //Number of tracks
  TClonesArray  *fTracks;            //->array with all tracks
  // static TClonesArray *fgTracks;

 public:
  Layer();
  Layer(Int_t N);
  virtual ~Layer();
  void Clear();
  static void Reset();
  void Print();
  Track        *AddTrack(Int_t event, Int_t layer);
  TClonesArray *GetTracks() const {return fTracks;}

   ClassDef(Layer, 1) // A layer
};




class Event : public TObject {
private:
  Int_t      fN; // event number
  Layer     *fLayers[2]; //->
  
 public:
  Event(Int_t N=0);
  virtual  ~Event();
  void      Clear(Option_t *option ="");
  
  Layer    *GetLayer(int i) { return fLayers[i];}
  void      SetN(Int_t N) {fN=N;} // sets event number
  void      Print();
  ClassDef(Event,1)  //Event
};



#endif
